# Generated by roxygen2: do not edit by hand

S3method(print,llmcoder_config)
export(addin_chat_panel)
export(addin_explain_code)
export(addin_fix_console_error)
export(addin_fix_selected_error)
export(addin_generate_from_comment)
export(addin_generate_with_preview)
export(addin_settings)
export(llmcoder_config)
export(llmcoder_setup)
export(ollama_list_models)
export(session_context_prompt)
export(session_context_report)
importFrom(htmltools,HTML)
importFrom(jsonlite,fromJSON)
importFrom(shiny,dialogViewer)
importFrom(shiny,req)
import(stringi)
importFrom(utils,getFromNamespace)
importFrom(utils,URLencode)
