% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/addins.R
\name{safe_get_ctx}
\alias{safe_get_ctx}
\title{Safely obtain the active editor context}
\usage{
safe_get_ctx()
}
\description{
Safely obtain the active editor context
}
\keyword{internal}
