% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/addins.R
\name{safe_call_llm}
\alias{safe_call_llm}
\title{Safely call the LLM, catching API errors}
\usage{
safe_call_llm(prompt, system_prompt, context)
}
\description{
Safely call the LLM, catching API errors
}
\keyword{internal}
