% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gadgets.R
\name{gadget_css}
\alias{gadget_css}
\title{Shared CSS for all gadgets}
\usage{
gadget_css()
}
\description{
Shared CSS for all gadgets
}
\keyword{internal}
