% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chat.R
\name{escape_html}
\alias{escape_html}
\title{Very simple markdown-to-HTML renderer for chat messages}
\usage{
escape_html(s)
}
\arguments{
\item{s}{Character string. Raw markdown text.}
}
\value{
Character string. Sanitised HTML fragment.
}
\description{
Handles fenced code blocks (\verb{```r ... ```}), inline code, bold, italic,
headings, and unordered lists.  No external dependencies required.
}
\keyword{internal}
