% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{call_ollama_history}
\alias{call_ollama_history}
\title{Ollama multi-turn (OpenAI-compatible endpoint)}
\usage{
call_ollama_history(messages, model, base_url)
}
\description{
Ollama multi-turn (OpenAI-compatible endpoint)
}
\keyword{internal}
