% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chat.R
\name{chat_js_handlers}
\alias{chat_js_handlers}
\title{Register Shiny custom message handlers for the Chat Panel}
\usage{
chat_js_handlers(session)
}
\arguments{
\item{session}{Shiny session object.}
}
\description{
Registers R-side handlers that respond to JavaScript events dispatched
by the Chat Panel UI (code-run button clicks, etc.).
}
\keyword{internal}
