% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/session-context.R
\name{.get_console_history}
\alias{.get_console_history}
\title{Console history from rstudioapi with ~/.Rhistory fallback}
\usage{
.get_console_history(max_hist = 30L)
}
\description{
Console history from rstudioapi with ~/.Rhistory fallback
}
\keyword{internal}
