% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{build_system_prompt}
\alias{build_system_prompt}
\title{System prompt for code generation}
\usage{
build_system_prompt()
}
\description{
System prompt for code generation
}
\keyword{internal}
