% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{call_openai_compat}
\alias{call_openai_compat}
\title{Generic OpenAI-compatible chat completions call}
\usage{
call_openai_compat(
  prompt,
  system_prompt,
  api_key,
  model,
  base_url,
  extra_hdrs = character()
)
}
\description{
Generic OpenAI-compatible chat completions call
}
\keyword{internal}
