% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{call_anthropic}
\alias{call_anthropic}
\title{Anthropic Messages API call}
\usage{
call_anthropic(prompt, system_prompt, api_key, model)
}
\description{
Anthropic Messages API call
}
\keyword{internal}
