% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/api.R
\name{call_openai_compat_history}
\alias{call_openai_compat_history}
\title{OpenAI-compatible multi-turn call}
\usage{
call_openai_compat_history(
  messages,
  api_key,
  model,
  base_url,
  extra_hdrs = character()
)
}
\arguments{
\item{messages}{List of message objects.}

\item{api_key}{API key.}

\item{model}{Model name.}

\item{base_url}{API base URL.}

\item{extra_hdrs}{Named character vector of extra headers.}
}
\description{
OpenAI-compatible multi-turn call
}
\keyword{internal}
